@@ -23,10 +23,10 @@ defaultMarkdown = u'''
 
 def formatTemplate(detail, template=defaultMarkdown):
 	template = template.format(
-		PROJECT_NAME=detail.get('PROJECT_NAME'),
+		PROJECT_NAME=detail.PROJECT_NAME,
 		TITLE=detail.get('title'),
 		MESSAGE=detail.get('message').get('formatted'),
-		URL=detail.get('URL'),
+		URL=detail.URL,
 		ENV=detail.get('environment'),
 		PLATFORM=detail.get('platform'),
 		DATETIME=detail.get('datetime'),
